unit UCudaRT_V2;

interface

const
  DLLNAME = 'cudart32_40_17.dll';


  cudaHostAllocDefault	= $00;	(**< Default page-locked allocation flag *)
  cudaHostAllocPortable	= $01;	(**< Pinned memory accessible by all CUDA contexts *)
  cudaHostAllocMapped	= $02;	(**< Map allocation into device space *)
  cudaHostAllocWriteCombined	= $04;	(**< Write-combined memory *)

  cudaHostRegisterDefault	= $00;	(**< Default host memory registration flag *)
  cudaHostRegisterPortable	= $01;	(**< Pinned memory accessible by all CUDA contexts *)
  cudaHostRegisterMapped	= $02;	(**< Map registered memory into device space *)

  cudaPeerAccessDefault	= $00;	(**< Default peer addressing enable flag *)

  cudaEventDefault	= $00;	(**< Default event flag *)
  cudaEventBlockingSync	= $01;	(**< Event uses blocking synchronization *)
  cudaEventDisableTiming	= $02;	(**< Event will not record timing data *)

  cudaDeviceScheduleAuto	= $00;	(**< Device flag - Automatic scheduling *)
  cudaDeviceScheduleSpin	= $01;	(**< Device flag - Spin default scheduling *)
  cudaDeviceScheduleYield	= $02;	(**< Device flag - Yield default scheduling *)
  cudaDeviceScheduleBlockingSync	= $04;	(**< Device flag - Use blocking synchronization *)
  cudaDeviceBlockingSync	= $04;	(**< Device flag - Use blocking synchronization \deprecated *)
  cudaDeviceMapHost	= $08;	(**< Device flag - Support mapped pinned allocations *)
  cudaDeviceLmemResizeToMax	= $10;	(**< Device flag - Keep local memory allocation after launch *)
  cudaDeviceMask	= $1f;	(**< Device flags mask *)

  cudaArrayDefault	= $00;	(**< Default CUDA array allocation flag *)
  cudaArrayLayered	= $01;	(**< Must be set in cudaMalloc3DArray to create a layered texture *)
  cudaArraySurfaceLoadStore	= $02;	(**< Must be set in cudaMallocArray in order to bind surfaces to the CUDA array *)

(**
 * CUDA error types
 *)
(*DEVICE_BUILTIN*)
type
  size_t = cardinal;

  cudaError = (
	(**
   * The API call returned with no errors. In the case of query calls, this
   * can also mean that the operation being queried is complete (see
   * ::cudaEventQuery() and ::cudaStreamQuery()).
   *)
	 cudaSuccess	= 0,

	(**
   * The device function being invoked (usually via ::cudaLaunch()) was not
   * previously configured via the ::cudaConfigureCall() function.
   *)
	 cudaErrorMissingConfiguration	= 1,

	(**
   * The API call failed because it was unable to allocate enough memory to
   * perform the requested operation.
   *)
	 cudaErrorMemoryAllocation	= 2,

	(**
   * The API call failed because the CUDA driver and runtime could not be
   * initialized.
   *)
	 cudaErrorInitializationError	= 3,

	(**
   * An exception occurred on the device while executing a kernel. Common
   * causes include dereferencing an invalid device pointer and accessing
   * out of bounds shared memory. The device cannot be used until
   * ::cudaThreadExit() is called. All existing device memory allocations
   * are invalid and must be reconstructed if the program is to continue
   * using CUDA.
   *)
	 cudaErrorLaunchFailure	= 4,

	(**
   * This indicated that a previous kernel launch failed. This was previously
   * used for device emulation of kernel launches.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorPriorLaunchFailure	= 5,

	(**
   * This indicates that the device kernel took too long to execute. This can
   * only occur if timeouts are enabled - see the device property
   * \ref ::cudaDeviceProp::kernelExecTimeoutEnabled "kernelExecTimeoutEnabled"
   * for more information. The device cannot be used until ::cudaThreadExit()
   * is called. All existing device memory allocations are invalid and must be
   * reconstructed if the program is to continue using CUDA.
   *)
	 cudaErrorLaunchTimeout	= 6,

	(**
   * This indicates that a launch did not occur because it did not have
   * appropriate resources. Although this error is similar to
   * ::cudaErrorInvalidConfiguration, this error usually indicates that the
   * user has attempted to pass too many arguments to the device kernel, or the
   * kernel launch specifies too many threads for the kernel's register count.
   *)
	 cudaErrorLaunchOutOfResources	= 7,

	(**
   * The requested device function does not exist or is not compiled for the
   * proper device architecture.
   *)
	 cudaErrorInvalidDeviceFunction	= 8,

	(**
   * This indicates that a kernel launch is requesting resources that can
   * never be satisfied by the current device. Requesting more shared memory
   * per block than the device supports will trigger this error, as will
   * requesting too many threads or blocks. See ::cudaDeviceProp for more
   * device limitations.
   *)
	 cudaErrorInvalidConfiguration	= 9,

	(**
   * This indicates that the device ordinal supplied by the user does not
   * correspond to a valid CUDA device.
   *)
	 cudaErrorInvalidDevice	= 10,

	(**
   * This indicates that one or more of the parameters passed to the API call
   * is not within an acceptable range of values.
   *)
	 cudaErrorInvalidValue	= 11,

	(**
   * This indicates that one or more of the pitch-related parameters passed
   * to the API call is not within the acceptable range for pitch.
   *)
	 cudaErrorInvalidPitchValue	= 12,

	(**
   * This indicates that the symbol name/identifier passed to the API call
   * is not a valid name or identifier.
   *)
	 cudaErrorInvalidSymbol	= 13,

	(**
   * This indicates that the buffer object could not be mapped.
   *)
	 cudaErrorMapBufferObjectFailed	= 14,

	(**
   * This indicates that the buffer object could not be unmapped.
   *)
	 cudaErrorUnmapBufferObjectFailed	= 15,

	(**
   * This indicates that at least one host pointer passed to the API call is
   * not a valid host pointer.
   *)
	 cudaErrorInvalidHostPointer	= 16,

	(**
   * This indicates that at least one device pointer passed to the API call is
   * not a valid device pointer.
   *)
	 cudaErrorInvalidDevicePointer	= 17,

	(**
   * This indicates that the texture passed to the API call is not a valid
   * texture.
   *)
	 cudaErrorInvalidTexture	= 18,

	(**
   * This indicates that the texture binding is not valid. This occurs if you
   * call ::cudaGetTextureAlignmentOffset() with an unbound texture.
   *)
	 cudaErrorInvalidTextureBinding	= 19,

	(**
   * This indicates that the channel descriptor passed to the API call is not
   * valid. This occurs if the format is not one of the formats specified by
   * ::cudaChannelFormatKind, or if one of the dimensions is invalid.
   *)
	 cudaErrorInvalidChannelDescriptor	= 20,

	(**
   * This indicates that the direction of the memcpy passed to the API call is
   * not one of the types specified by ::cudaMemcpyKind.
   *)
	 cudaErrorInvalidMemcpyDirection	= 21,

	(**
   * This indicated that the user has taken the address of a constant variable,
   * which was forbidden up until the CUDA 3.1 release.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Variables in constant
   * memory may now have their address taken by the runtime via
   * ::cudaGetSymbolAddress().
   *)
	 cudaErrorAddressOfConstant	= 22,

	(**
   * This indicated that a texture fetch was not able to be performed.
   * This was previously used for device emulation of texture operations.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorTextureFetchFailed	= 23,

	(**
   * This indicated that a texture was not bound for access.
   * This was previously used for device emulation of texture operations.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorTextureNotBound	= 24,

	(**
   * This indicated that a synchronization operation had failed.
   * This was previously used for some device emulation functions.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorSynchronizationError	= 25,

	(**
   * This indicates that a non-float texture was being accessed with linear
   * filtering. This is not supported by CUDA.
   *)
	 cudaErrorInvalidFilterSetting	= 26,

	(**
   * This indicates that an attempt was made to read a non-float texture as a
   * normalized float. This is not supported by CUDA.
   *)
	 cudaErrorInvalidNormSetting	= 27,

	(**
   * Mixing of device and device emulation code was not allowed.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorMixedDeviceExecution	= 28,

	(**
   * This indicated an issue with calling API functions during the unload
   * process of the CUDA runtime in prior releases.
   * \deprecated
   * This error return is deprecated as of CUDA 3.2.
   *)
	 cudaErrorCudartUnloading	= 29,

	(**
   * This indicates that an unknown internal error has occurred.
   *)
	 cudaErrorUnknown	= 30,

	(**
   * This indicates that the API call is not yet implemented. Production
   * releases of CUDA will never return this error.
   *)
	 cudaErrorNotYetImplemented	= 31,

	(**
   * This indicated that an emulated device pointer exceeded the 32-bit address
   * range.
   * \deprecated
   * This error return is deprecated as of CUDA 3.1. Device emulation mode was
   * removed with the CUDA 3.1 release.
   *)
	 cudaErrorMemoryValueTooLarge	= 32,

	(**
   * This indicates that a resource handle passed to the API call was not
   * valid. Resource handles are opaque types like ::cudaStream_t and
   * ::cudaEvent_t.
   *)
	 cudaErrorInvalidResourceHandle	= 33,

	(**
   * This indicates that asynchronous operations issued previously have not
   * completed yet. This result is not actually an error, but must be indicated
   * differently than ::cudaSuccess (which indicates completion). Calls that
   * may return this value include ::cudaEventQuery() and ::cudaStreamQuery().
   *)
	 cudaErrorNotReady	= 34,

	(**
   * This indicates that the installed NVIDIA CUDA driver is older than the
   * CUDA runtime library. This is not a supported configuration. Users should
   * install an updated NVIDIA display driver to allow the application to run.
   *)
	 cudaErrorInsufficientDriver	= 35,

	(**
   * This indicates that the user has called ::cudaSetDevice(),
   * ::cudaSetValidDevices(), ::cudaSetDeviceFlags(),
   * ::cudaD3D9SetDirect3DDevice(), ::cudaD3D10SetDirect3DDevice,
   * ::cudaD3D11SetDirect3DDevice(), * or ::cudaVDPAUSetVDPAUDevice() after
   * initializing the CUDA runtime by calling non-device management operations
   * (allocating memory and launching kernels are examples of non-device
   * management operations). This error can also be returned if using
   * runtime/driver interoperability and there is an existing ::CUcontext
   * active on the host thread.
   *)
	 cudaErrorSetOnActiveProcess	= 36,

	(**
   * This indicates that the surface passed to the API call is not a valid
   * surface.
   *)
	 cudaErrorInvalidSurface	= 37,

	(**
   * This indicates that no CUDA-capable devices were detected by the installed
   * CUDA driver.
   *)
	 cudaErrorNoDevice	= 38,

	(**
   * This indicates that an uncorrectable ECC error was detected during
   * execution.
   *)
	 cudaErrorECCUncorrectable	= 39,

	(**
   * This indicates that a link to a shared object failed to resolve.
   *)
	 cudaErrorSharedObjectSymbolNotFound	= 40,

	(**
   * This indicates that initialization of a shared object failed.
   *)
	 cudaErrorSharedObjectInitFailed	= 41,

	(**
   * This indicates that the ::cudaLimit passed to the API call is not
   * supported by the active device.
   *)
	 cudaErrorUnsupportedLimit	= 42,

	(**
   * This indicates that multiple global or constant variables (across separate
   * CUDA source files in the application) share the same string name.
   *)
	 cudaErrorDuplicateVariableName	= 43,

	(**
   * This indicates that multiple textures (across separate CUDA source
   * files in the application) share the same string name.
   *)
	 cudaErrorDuplicateTextureName	= 44,

	(**
   * This indicates that multiple surfaces (across separate CUDA source
   * files in the application) share the same string name.
   *)
	 cudaErrorDuplicateSurfaceName	= 45,

	(**
   * This indicates that all CUDA devices are busy or unavailable at the current
   * time. Devices are often busy/unavailable due to use of
   * ::cudaComputeModeExclusive, ::cudaComputeModeProhibited or when long
   * running CUDA kernels have filled up the GPU and are blocking new work
   * from starting. They can also be unavailable due to memory constraints
   * on a device that already has active CUDA work being performed.
   *)
	 cudaErrorDevicesUnavailable	= 46,

	(**
   * This indicates that the device kernel image is invalid.
   *)
	 cudaErrorInvalidKernelImage	= 47,

	(**
   * This indicates that there is no kernel image available that is suitable
   * for the device. This can occur when a user specifies code generation
   * options for a particular CUDA source file that do not include the
   * corresponding device configuration.
   *)
	 cudaErrorNoKernelImageForDevice	= 48,

	(**
   * This indicates that the current context is not compatible with this
   * the CUDA Runtime. This can only occur if you are using CUDA
   * Runtime/Driver interoperability and have created an existing Driver
   * context using the driver API. The Driver context may be incompatible
   * either because the Driver context was created using an older version
   * of the API, because the Runtime API call expects a primary driver
   * contextand the Driver context is not primary, or because the Driver
   * context has been destroyed. Please see \ref CUDART_DRIVER "Interactions
   * with the CUDA Driver API" for more information.
   *)
	 cudaErrorIncompatibleDriverContext	= 49,

	(**
   * This error indicates that a call to ::cudaDeviceEnablePeerAccess() is
   * trying to re-enable peer addressing on from a context which has already
   * had peer addressing enabled.
   *)
	 cudaErrorPeerAccessAlreadyEnabled	= 50,

	(**
   * This error indicates that ::cudaDeviceDisablePeerAccess() is trying to
   * disable peer addressing which has not been enabled yet via
   * ::cudaDeviceEnablePeerAccess().
   *)
	 cudaErrorPeerAccessNotEnabled	= 51,

	(**
   * This indicates that a call tried to access an exclusive-thread device that
   * is already in use by a different thread.
   *)
	 cudaErrorDeviceAlreadyInUse	= 54,

	(**
   * This indicates profiler has been disabled for this run and thus runtime
   * APIs cannot be used to profile subsets of the program. This can
   * happen when the application is running with external profiling tools
   * like visual profiler.
   *)
	 cudaErrorProfilerDisabled	= 55,

	(**
   * This indicates profiler has not been initialized yet. cudaProfilerInitialize()
   * must be called before calling cudaProfilerStart and cudaProfilerStop to
   * initialize profiler.
   *)
	 cudaErrorProfilerNotInitialized	= 56,

	(**
   * This indicates profiler is already started. This error can be returned if
   * cudaProfilerStart() is called multiple times without subsequent call
   * to cudaProfilerStop().
   *)
	 cudaErrorProfilerAlreadyStarted	= 57,

	(**
   * This indicates profiler is already stopped. This error can be returned if
   * cudaProfilerStop() is called without starting profiler using cudaProfilerStart().
   *)
	 cudaErrorProfilerAlreadyStopped	= 58,

	(**
   * This indicates an internal startup failure in the CUDA runtime.
   *)
	 cudaErrorStartupFailure	= $7,

	(**
   * Any unhandled CUDA driver error is added to this value and returned via
   * the runtime. Production releases of CUDA should not return such errors.
   *)
	 cudaErrorApiFailureBase	= 10000
	 );

{+//DEVICE_BUILTIN*/ }
  cudaChannelFormatKind = (
    cudaChannelFormatKindSigned, 
    cudaChannelFormatKindUnsigned, 
    cudaChannelFormatKindFloat  );

{+//DEVICE_BUILTIN*/ }
  PcudaChannelFormatDesc = ^cudaChannelFormatDesc;
  cudaChannelFormatDesc = record
    x: Integer;
    y: Integer;
    z: Integer;
    w: Integer;
    f: cudaChannelFormatKind;
  end {cudaChannelFormatDesc};

{+//DEVICE_BUILTIN*/ }
  cudaArray = record end;//!ATTENTION foreward Declaration?)

{+//DEVICE_BUILTIN*/ }
  cudaMemcpyKind = (
    cudaMemcpyHostToHost {= 0},
    cudaMemcpyHostToDevice,
    cudaMemcpyDeviceToHost, 
    cudaMemcpyDeviceToDevice  );

{+//DEVICE_BUILTIN*/ }
  cudaPitchedPtr = record
    ptr: Pointer;
    pitch: Cardinal;
    xsize: Cardinal;
    ysize: Cardinal;
  end {cudaPitchedPtr};

{+//DEVICE_BUILTIN*/ }
  cudaExtent = record
    width: Cardinal;
    height: Cardinal;
    depth: Cardinal;
  end {cudaExtent};

{+//DEVICE_BUILTIN*/ }
  cudaPos = record
    x: Cardinal;
    y: Cardinal;
    z: Cardinal;
  end {cudaPos};

{+//DEVICE_BUILTIN*/ }
  cudaMemcpy3DParms = record
    srcArray: Pointer;
    srcPos: cudaPos;
    srcPtr: cudaPitchedPtr;
    dstArray: Pointer;
    dstPos: cudaPos;
    dstPtr: cudaPitchedPtr;
    extent: cudaExtent;
    kind: cudaMemcpyKind;
  end {cudaMemcpy3DParms};

(**
 * CUDA function cache configurations
 *)
(*DEVICE_BUILTIN*)
  cudaFuncCache = (
	 cudaFuncCachePreferNone	= 0, (**< Default function cache configuration, no preference *)
	 cudaFuncCachePreferShared	= 1, (**< Prefer larger shared memory and smaller L1 cache  *)
	 cudaFuncCachePreferL1	= 2 (**< Prefer larger L1 cache and smaller shared memory *)
	 );

(**
 * CUDA device compute modes
 *)
(*DEVICE_BUILTIN*)
  cudaComputeMode = (
	 cudaComputeModeDefault	= 0, (**< Default compute mode (Multiple threads can use ::cudaSetDevice() with this device) *)
	 cudaComputeModeExclusive	= 1, (**< Compute-exclusive-thread mode (Only one thread in one process will be able to use ::cudaSetDevice() with this device) *)
	 cudaComputeModeProhibited	= 2, (**< Compute-prohibited mode (No threads can use ::cudaSetDevice() with this device) *)
	 cudaComputeModeExclusiveProcess	= 3 (**< Compute-exclusive-process mode (Many threads in one process will be able to use ::cudaSetDevice() with this device) *)
	 );

(**
 * CUDA Limits
 *)
(*DEVICE_BUILTIN*)
  cudaLimit = (
	 cudaLimitStackSize	= $00, (**< GPU thread stack size *)
	 cudaLimitPrintfFifoSize	= $01, (**< GPU printf FIFO size *)
	 cudaLimitMallocHeapSize	= $02 (**< GPU malloc heap size *)
	 );

(**
 * CUDA Profiler Output modes
 *)
(*DEVICE_BUILTIN*)
  cudaOutputMode = (
	 cudaKeyValuePair	= $00, (**< Output mode Key-Value pair format. *)
	 cudaCSV	= $01 (**< Output mode Comma separated values format. *)
	 );


{+//DEVICE_BUILTIN*/ }
  PcudaDeviceProp = ^cudaDeviceProp;
  (**
 * CUDA device properties
 *)
(*DEVICE_BUILTIN*)
  p_cudaDeviceProp = ^cudaDeviceProp;
  cudaDeviceProp = record
	name	: array[0..255] of char;	(**< ASCII string identifying device *)
	totalGlobalMem	: size_t;	(**< Global memory available on device in bytes *)
	sharedMemPerBlock	: size_t;	(**< Shared memory available per block in bytes *)
	regsPerBlock	: Integer;	(**< 32-bit registers available per block *)
	warpSize	: Integer;	(**< Warp size in threads *)
	memPitch	: size_t;	(**< Maximum pitch in bytes allowed by memory copies *)
	maxThreadsPerBlock	: Integer;	(**< Maximum number of threads per block *)
	maxThreadsDim	: array[0..2] of Integer;	(**< Maximum size of each dimension of a block *)
	maxGridSize	: array[0..2] of Integer;	(**< Maximum size of each dimension of a grid *)
	clockRate	: Integer;	(**< Clock frequency in kilohertz *)
	totalConstMem	: size_t;	(**< Constant memory available on device in bytes *)
	major	: Integer;	(**< Major compute capability *)
	minor	: Integer;	(**< Minor compute capability *)
	textureAlignment	: size_t;	(**< Alignment requirement for textures *)
	deviceOverlap	: Integer;	(**< Device can concurrently copy memory and execute a kernel. Deprecated. Use instead asyncEngineCount. *)
	multiProcessorCount	: Integer;	(**< Number of multiprocessors on device *)
	kernelExecTimeoutEnabled	: Integer;	(**< Specified whether there is a run time limit on kernels *)
	integrated	: Integer;	(**< Device is integrated as opposed to discrete *)
	canMapHostMemory	: Integer;	(**< Device can map host memory with cudaHostAlloc/cudaHostGetDevicePointer *)
	computeMode	: Integer;	(**< Compute mode (See ::cudaComputeMode) *)
	maxTexture1D	: Integer;	(**< Maximum 1D texture size *)
	maxTexture2D	: array[0..1] of Integer;	(**< Maximum 2D texture dimensions *)
	maxTexture3D	: array[0..2] of Integer;	(**< Maximum 3D texture dimensions *)
	maxTexture1DLayered	: array[0..1] of Integer;	(**< Maximum 1D layered texture dimensions *)
	maxTexture2DLayered	: array[0..2] of Integer;	(**< Maximum 2D layered texture dimensions *)
	surfaceAlignment	: size_t;	(**< Alignment requirements for surfaces *)
	concurrentKernels	: Integer;	(**< Device can possibly execute multiple kernels concurrently *)
	ECCEnabled	: Integer;	(**< Device has ECC support enabled *)
	pciBusID	: Integer;	(**< PCI bus ID of the device *)
	pciDeviceID	: Integer;	(**< PCI device ID of the device *)
	pciDomainID	: Integer;	(**< PCI domain ID of the device *)
	tccDriver	: Integer;	(**< 1 if device is a Tesla device using TCC driver, 0 otherwise *)
	asyncEngineCount	: Integer;	(**< Number of asynchronous engines *)
	unifiedAddressing	: Integer;	(**< Device shares a unified address space with the host *)
	memoryClockRate	: Integer;	(**< Peak memory clock frequency in kilohertz *)
	memoryBusWidth	: Integer;	(**< Global memory bus width in bits *)
	l2CacheSize	: Integer;	(**< Size of L2 cache in bytes *)
	maxThreadsPerMultiProcessor	: Integer;	(**< Maximum resident threads per multiprocessor *)
  end;

{+//****************************************************************************** }
{-** }
{-* SHORTHAND TYPE DEFINITION USED BY RUNTIME API* }
{-** }
{=*******************************************************************************/ }
(**
 * CUDA Error types
 *)                                         
(*DEVICE_BUILTIN*)
  cudaError_t = cudaError;
(**
 * CUDA stream
 *)
(*DEVICE_BUILTIN*)
  CUstream_st = record
  end;
  cudaStream_t	= ^CUstream_st;

(**
 * CUDA event types
 *)
(*DEVICE_BUILTIN*)
  CUevent_st = record
  end;
  cudaEvent_t	= ^CUevent_st;

(**
 * CUDA graphics resource types
 *)
(*DEVICE_BUILTIN*)
   cudaGraphicsResource = record
   end;
  cudaGraphicsResource_t	= ^cudaGraphicsResource;

(**
 * CUDA UUID types
 *)
(*DEVICE_BUILTIN*)
 // cudaUUID_t	= CUuuid_st;

(**
 * CUDA output file modes
 *)
(*DEVICE_BUILTIN*)



function cudaMalloc(devPtr: Pointer;
                    size: Cardinal): cudaError_t; stdcall ; external DLLNAME name 'cudaMalloc';

function cudaMallocHost(ptr: Pointer;
                        size: Cardinal): cudaError_t; stdcall ; external DLLNAME name 'cudaMallocHost';

function cudaMallocPitch(devPtr: Pointer;
                         pitch: Cardinal;
                         width: Cardinal;
                         height: Cardinal): cudaError_t; stdcall ; external DLLNAME name 'cudaMallocPitch';

function cudaMallocArray(aarray: Pointer;
                         desc: cudaChannelFormatDesc;
                         width: Cardinal;
                         height : Cardinal): cudaError_t; stdcall ; external DLLNAME name 'cudaMallocArray';

function cudaFree(devPtr: Pointer): cudaError_t; stdcall ; external DLLNAME name 'cudaFree';

function cudaFreeHost(ptr: Pointer): cudaError_t; stdcall ; external DLLNAME name 'cudaFreeHost';

function cudaFreeArray(const aarray: Pointer): cudaError_t; stdcall ; external DLLNAME name 'cudaFreeArray';

function cudaMemcpy(dst: Pointer; src: Pointer; count: Cardinal;
                    kind: cudaMemcpyKind) : cudaError_t; stdcall ; external DLLNAME name 'cudaMemcpy';


{+//****************************************************************************** }
{-** }
{-** }
{-** }
{=****************************************************************************** }


function cudaGetDeviceCount(var count: Integer): cudaError_t; stdcall ; external DLLNAME name 'cudaGetDeviceCount';

function cudaGetDeviceProperties(var prop: cudaDeviceProp;
                                 device: Integer): cudaError_t; stdcall ; external DLLNAME name 'cudaGetDeviceProperties';

function cudaChooseDevice(var device: Integer;
                          const prop: PcudaDeviceProp): cudaError_t; stdcall ; external DLLNAME name 'cudaChooseDevice';

function cudaSetDevice(device: Integer): cudaError_t;  stdcall ; external DLLNAME name 'cudaSetDevice';

function cudaGetDevice(var device: Integer): cudaError_t;  stdcall ; external DLLNAME name 'cudaGetDevice';

{+//****************************************************************************** }
{-** }
{-** }
{-** }
{=*******************************************************************************/ }


function cudaGetLastError: cudaError_t; stdcall ; external DLLNAME name 'cudaGetLastError';

function cudaGetErrorString(error: cudaError_t): PChar; stdcall ; external DLLNAME name 'cudaGetErrorString';


implementation

end.
